pub struct MessageParam {
pub content: Vec<ContentBlockParam>,
pub role: String,
}Fields
content: Vec<ContentBlockParam>role: StringImplementations
Sourceimpl MessageParam
impl MessageParam
Sourcepub fn new(content: &Bound<'_, PyAny>, role: String) -> Result<Self, TypeError>
pub fn new(content: &Bound<'_, PyAny>, role: String) -> Result<Self, TypeError>
Create a new MessageParam Will accept either a string, Single type of ContentBlockParam, or a list of varying ContentBlockParams Initial logic determines initial type and processes accordingly If string, wraps in TextBlockParam –> ContentBlockParam If single param, pass to ContentBlockParam directly If list, process each item in list to ContentBlockParam
pub fn __str__(&self) -> String
pub fn model_dump<'py>( &self, py: Python<'py>, ) -> Result<Bound<'py, PyAny>, TypeError>
pub fn text(&self) -> String
Sourceimpl MessageParam
impl MessageParam
Sourcepub fn to_text_block_param(&self) -> Result<TextBlockParam, TypeError>
pub fn to_text_block_param(&self) -> Result<TextBlockParam, TypeError>
Helper function to create a MessageParam from a single TextBlockParam