pub enum ProviderRequest {
OpenAIV1(OpenAIChatCompletionRequestV1),
AnthropicV1(AnthropicMessageRequestV1),
GeminiV1(GeminiGenerateContentRequestV1),
}Expand description
Unified enum for provider-specific requests This serves as a central access point for accessing request attributes from within a Prompt
Variants
OpenAIV1(OpenAIChatCompletionRequestV1)
AnthropicV1(AnthropicMessageRequestV1)
GeminiV1(GeminiGenerateContentRequestV1)
Implementations
Sourceimpl ProviderRequest
impl ProviderRequest
pub fn insert_message(&mut self, message: MessageNum, idx: Option<usize>)
pub fn push_message(&mut self, message: MessageNum)
pub fn messages(&self) -> &[MessageNum]
pub fn system_instructions(&self) -> Vec<&MessageNum>
pub fn messages_mut(&mut self) -> &mut Vec<MessageNum>
pub fn add_tools( &mut self, tools: Vec<AgentToolDefinition>, ) -> Result<(), TypeError>
pub fn prepend_system_instructions( &mut self, instructions: Vec<MessageNum>, ) -> Result<(), TypeError>
pub fn response_json_schema(&self) -> Option<&Value>
pub fn has_structured_output(&self) -> bool
Sourcepub fn to_request(&self, provider: &Provider) -> Result<Value, TypeError>
pub fn to_request(&self, provider: &Provider) -> Result<Value, TypeError>
Retrieve the JSON request body for the specified provider This method will first attempt to match the provider type, returning an error if there is a mismatch.
pub fn set_response_json_schema(&mut self, response_json_schema: Option<Value>)