Prompt

Struct Prompt 

pub struct Prompt {
    pub request: ProviderRequest,
    pub model: String,
    pub provider: Provider,
    pub version: String,
    pub parameters: Vec<String>,
    pub response_type: ResponseType,
}

Fields

request: ProviderRequestmodel: Stringprovider: Providerversion: Stringparameters: Vec<String>response_type: ResponseType

Implementations

Source

impl Prompt

pub fn new( py: Python<'_>, messages: &Bound<'_, PyAny>, model: &str, provider: &Bound<'_, PyAny>, system_instructions: Option<&Bound<'_, PyAny>>, model_settings: Option<&Bound<'_, PyAny>>, output_type: Option<&Bound<'_, PyAny>>, ) -> Result<Self, TypeError>

Creates a new Prompt object. Main parsing logic is as follows:

  1. Extract model settings if provided, otherwise use provider default settings.
  2. Message and system instructions are expected to be a variant of MessageNum (OpenAIChatMessage, AnthropicMessage or GeminiContent).
  3. On instantiation, message will be check if is_instance_of pystring. If pystring, provider will be used to map to appropriate message Text type
  4. If message is a pylist, each item will be checked for is_instance_of pystring or MessageNum variant and converted accordingly.
  5. If message is a single MessageNum variant, it will be extracted and wrapped in a vec.
  6. After messages are parsed, a full provider request struct will by built using to_provider_request function.
Arguments:
  • message: A single message or list of messages representing user input.
  • model: The model identifier to use for the prompt.
  • provider: The provider to use for the prompt.
  • system_instruction: Optional system instruction message or list of messages.
  • model_settings: Optional model settings to use for the prompt.
  • output_type: Optional output type to enforce structured output.
pub fn model_settings<'py>( &self, py: Python<'py>, ) -> Result<Bound<'py, PyAny>, TypeError>

pub fn model_identifier(&self) -> String

pub fn save_prompt(&self, path: Option<PathBuf>) -> PyResult<PathBuf>

pub fn from_path(path: PathBuf) -> Result<Self, TypeError>

pub fn model_validate_json(json_string: String) -> Result<Self, TypeError>

pub fn model_dump_json(&self) -> String

pub fn __str__(&self) -> String

pub fn all_messages<'py>( &self, py: Python<'py>, ) -> Result<Bound<'py, PyList>, TypeError>

Returns all messages as Python objects, including system instructions, user messages, and assistant messages.

pub fn messages<'py>( &self, py: Python<'py>, ) -> Result<Bound<'py, PyList>, TypeError>

Returns User messages as Python objects. This means, system instructions are excluded.

pub fn message<'py>( &self, py: Python<'py>, ) -> Result<Bound<'py, PyAny>, TypeError>

Returns the last User message as a Python object. This means, system instructions are excluded.

pub fn openai_messages(&self) -> Result<OpenAIMessageList, TypeError>

Returns the messages as OpenAI ChatMessage Python objects This is a helper that provide strict typing when working with OpenAI prompts

pub fn openai_message(&self) -> Result<OpenAIChatMessage, TypeError>

Returns the last message as an OpenAI ChatMessage Python object This is a helper that provide strict typing when working with OpenAI prompts

pub fn gemini_messages(&self) -> Result<GeminiContentList, TypeError>

Returns the messages as Google GeminiContent Python objects This is a helper that provide strict typing when working with Google/Gemini/Vertex prompts

pub fn gemini_message(&self) -> Result<GeminiContent, TypeError>

Returns the last message as a Google GeminiContent Python object This is a helper that provide strict typing when working with Google/Gemini/Vertex prompts

pub fn anthropic_messages(&self) -> Result<AnthropicMessageList, TypeError>

pub fn anthropic_message(&self) -> Result<AnthropicMessage, TypeError>

Returns the last message as an Anthropic MessageParam Python object

pub fn system_instructions<'py>( &self, py: Python<'py>, ) -> Result<Bound<'py, PyList>, TypeError>

pub fn bind( &self, name: Option<&str>, value: Option<&Bound<'_, PyAny>>, kwargs: Option<&Bound<'_, PyDict>>, ) -> Result<Self, TypeError>

Binds a variable in the prompt to a value. This will return a new Prompt with the variable bound to the value. This will iterate over all user messages and bind the variable in each message.

Arguments:
  • name: The name of the variable to bind.
  • value: The value to bind the variable to.
Returns:
  • Result<Self, PromptError>: Returns a new Prompt with the variable bound to the value.
pub fn bind_mut( &mut self, name: Option<&str>, value: Option<&Bound<'_, PyAny>>, kwargs: Option<&Bound<'_, PyDict>>, ) -> Result<(), TypeError>

Binds a variable in the prompt to a value. This will mutate the current Prompt and bind the variable in each user message.

Arguments:
  • name: The name of the variable to bind.
  • value: The value to bind the variable to.
Returns:
  • Result<(), PromptError>: Returns Ok(()) on success or an error if the binding fails.
pub fn response_json_schema_pretty(&self) -> Option<String>

pub fn response_json_schema_py(&self) -> Option<String>

pub fn model_dump<'py>( &self, py: Python<'py>, ) -> Result<Bound<'py, PyAny>, TypeError>

Source

impl Prompt

pub fn from_generic_config( config: GenericPromptConfig, ) -> Result<Self, TypeError>

Converts a generic prompt configuration to a Prompt instance. This handles the user-friendly YAML/JSON format parsing.

pub fn response_json_schema(&self) -> Option<&Value>

pub fn new_rs( messages: Vec<MessageNum>, model: &str, provider: Provider, system_instructions: Vec<MessageNum>, model_settings: Option<ModelSettings>, response_json_schema: Option<Value>, response_type: ResponseType, ) -> Result<Self, TypeError>

pub fn add_tools( &mut self, tools: Vec<AgentToolDefinition>, ) -> Result<(), TypeError>

pub fn extract_variables( messages: &[MessageNum], system_instructions: &[MessageNum], ) -> Vec<String>

pub fn model_dump_value(&self) -> Value

pub fn to_request_json(&self) -> Result<Value, TypeError>

pub fn set_response_json_schema( &mut self, response_json_schema: Option<Value>, response_type: ResponseType, )